======
Phileo
======

a generic user liking app


Attribution
-----------

The default liking AJAX liking widget that ships with this package uses the Iconic icons packaged
into a typeface from http://somerandomdude.com/work/iconic/.